pub struct WordBreakIteratorUtf16<'a>(WordBreakIterator<'a, 'a, Utf16>);Tuple Fields
0: WordBreakIterator<'a, 'a, Utf16>Implementations
Sourceimpl<'a> WordBreakIteratorUtf16<'a>
impl<'a> WordBreakIteratorUtf16<'a>
Sourcepub fn next(&mut self) -> i32
pub fn next(&mut self) -> i32
Finds the next breakpoint. Returns -1 if at the end of the string or if the index is out of range of a 32-bit signed integer.
Sourcepub fn word_type(&self) -> SegmenterWordType
pub fn word_type(&self) -> SegmenterWordType
Return the status value of break boundary.
Sourcepub fn is_word_like(&self) -> bool
pub fn is_word_like(&self) -> bool
Return true when break boundary is word-like such as letter/number/CJK